@@ -54,12 +54,13 @@ void Notepad_plus_Window::setStartupBgColor(COLORREF BgColor)
 	RECT windowClientArea;
 	HDC hdc = GetDCEx(_hSelf, NULL, DCX_CACHE | DCX_LOCKWINDOWUPDATE); //lock window update flag due to PaintLocker
 	GetClientRect(_hSelf, &windowClientArea);
-	FillRect(hdc, &windowClientArea, CreateSolidBrush(BgColor));
+	HBRUSH hBrush = ::CreateSolidBrush(BgColor);
+	::FillRect(hdc, &windowClientArea, hBrush);
+	::DeleteObject(hBrush);
 	ReleaseDC(_hSelf, hdc);
 }
 
 
-
 void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdLine, CmdLineParams *cmdLineParams)
 {
 	Window::init(hInst, parent);
@@ -142,7 +143,7 @@ void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdL
 		::SetWindowPlacement(_hSelf,&posInfo);
 		
 		if (NppDarkMode::isEnabled())
-			setStartupBgColor(NppDarkMode::getBackgroundColor()); //draw dark background when opening Npp without position data
+			setStartupBgColor(NppDarkMode::getDlgBackgroundColor()); //draw dark background when opening Npp without position data
 	}
 
 	if ((nppGUI._tabStatus & TAB_MULTILINE) != 0)
@@ -193,7 +194,7 @@ void Notepad_plus_Window::init(HINSTANCE hInst, HWND parent, const wchar_t *cmdL
 	}
 
 	if(cmdLineParams->isPointValid() && NppDarkMode::isEnabled())
-		setStartupBgColor(NppDarkMode::getBackgroundColor()); //draw dark background when opening Npp through cmd with position data
+		setStartupBgColor(NppDarkMode::getDlgBackgroundColor()); //draw dark background when opening Npp through cmd with position data
 
 	std::vector<wstring> fileNames;
 	std::vector<wstring> patterns;
