@@ -112,13 +112,13 @@ intptr_t CALLBACK SharedParametersDialog::run_dlgProc(UINT Message, WPARAM wPara
 
         case WM_CTLCOLOREDIT:
         {
-            return NppDarkMode::onCtlColorSofter(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorCtrl(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_CTLCOLORDLG:
         case WM_CTLCOLORSTATIC:
         {
-            return NppDarkMode::onCtlColorDarker(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorDlg(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_PRINTCLIENT:
@@ -1094,13 +1094,14 @@ intptr_t CALLBACK UserDefineDialog::run_dlgProc(UINT message, WPARAM wParam, LPA
 
             NppDarkMode::autoSubclassAndThemeChildControls(_hSelf);
             NppDarkMode::setDarkScrollBar(_hSelf);
+            NppDarkMode::autoSubclassAndThemeWindowNotify(_hSelf);
 
             return TRUE;
         }
 
         case WM_CTLCOLOREDIT:
         {
-            return NppDarkMode::onCtlColorSofter(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorCtrl(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_CTLCOLORLISTBOX:
@@ -1111,7 +1112,7 @@ intptr_t CALLBACK UserDefineDialog::run_dlgProc(UINT message, WPARAM wParam, LPA
         case WM_CTLCOLORDLG:
         case WM_CTLCOLORSTATIC:
         {
-            return NppDarkMode::onCtlColorDarker(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorDlg(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_PRINTCLIENT:
@@ -1397,28 +1398,48 @@ intptr_t CALLBACK UserDefineDialog::run_dlgProc(UINT message, WPARAM wParam, LPA
                         wstring sourceFile = fDlg.doOpenSingleFileDlg();
                         if (sourceFile.empty()) break;
 
+                        NativeLangSpeaker* pNativeSpeaker = nppParam.getNativeLangSpeaker();
+
                         bool isSuccessful = nppParam.importUDLFromFile(sourceFile);
                         if (isSuccessful)
                         {
                             auto i = ::SendDlgItemMessage(_hSelf, IDC_LANGNAME_COMBO, CB_GETCURSEL, 0, 0);
                             reloadLangCombo();
                             ::SendDlgItemMessage(_hSelf, IDC_LANGNAME_COMBO, CB_SETCURSEL, i, 0);
-                            printStr(L"Import successful.");
+                            
+                            pNativeSpeaker->messageBox("UDL_importSuccessful",
+                                _hSelf,
+                                L"Import successful.",
+                                L"User Defined Language",
+                                MB_OK | MB_APPLMODAL,
+                                0);
                         }
                         else
                         {
-                            printStr(L"Fail to import.");
+                            pNativeSpeaker->messageBox("UDL_importFails",
+                                _hSelf,
+                                L"Failed to import.",
+                                L"User Defined Language",
+                                MB_OK | MB_APPLMODAL | MB_ICONEXCLAMATION,
+                                0);
                         }
                         break;
                     }
 
                     case IDC_EXPORT_BUTTON :
                     {
+                        NativeLangSpeaker* pNativeSpeaker = nppParam.getNativeLangSpeaker();
+
 						auto i2Export = ::SendDlgItemMessage(_hSelf, IDC_LANGNAME_COMBO, CB_GETCURSEL, 0, 0);
                         if (i2Export == 0)
                         {
                             // maybe a better option would be to simply send IDC_SAVEAS_BUTTON message, and display "Save As..." dialog?
-                            printStr(L"Before exporting, save your language definition by clicking \"Save As...\" button");
+                            pNativeSpeaker->messageBox("UDL_saveBeforeImport",
+                                _hSelf,
+                                L"Before exporting, save your language definition by clicking \"Save As...\" button",
+                                L"User Defined Language",
+                                MB_OK | MB_APPLMODAL,
+                                0);
                             break;
                         }
 
@@ -1433,11 +1454,21 @@ intptr_t CALLBACK UserDefineDialog::run_dlgProc(UINT message, WPARAM wParam, LPA
                             bool isSuccessful = nppParam.exportUDLToFile(i2Export - 1, fileName2save);
                             if (isSuccessful)
                             {
-                                printStr(L"Export successful");
+                                pNativeSpeaker->messageBox("UDL_exportSuccessful",
+                                    _hSelf,
+                                    L"Export successful.",
+                                    L"User Defined Language",
+                                    MB_OK | MB_APPLMODAL,
+                                    0);
                             }
                             else
                             {
-                                printStr(L"Fail to export.");
+                                pNativeSpeaker->messageBox("UDL_exportFails",
+                                    _hSelf,
+                                    L"Failed to export.",
+                                    L"User Defined Language",
+                                    MB_OK | MB_APPLMODAL | MB_ICONEXCLAMATION,
+                                    0);
                             }
                         }
                         break;
@@ -1605,13 +1636,13 @@ intptr_t CALLBACK StringDlg::run_dlgProc(UINT Message, WPARAM wParam, LPARAM lPa
 
 		case WM_CTLCOLOREDIT:
 		{
-			return NppDarkMode::onCtlColorSofter(reinterpret_cast<HDC>(wParam));
+			return NppDarkMode::onCtlColorCtrl(reinterpret_cast<HDC>(wParam));
 		}
 
 		case WM_CTLCOLORDLG:
 		case WM_CTLCOLORSTATIC:
 		{
-			return NppDarkMode::onCtlColorDarker(reinterpret_cast<HDC>(wParam));
+			return NppDarkMode::onCtlColorDlg(reinterpret_cast<HDC>(wParam));
 		}
 
 		case WM_PRINTCLIENT:
@@ -1623,18 +1654,6 @@ intptr_t CALLBACK StringDlg::run_dlgProc(UINT Message, WPARAM wParam, LPARAM lPa
 			break;
 		}
 
-		case WM_ERASEBKGND:
-		{
-			if (NppDarkMode::isEnabled())
-			{
-				RECT rc{};
-				getClientRect(rc);
-				::FillRect(reinterpret_cast<HDC>(wParam), &rc, NppDarkMode::getDarkerBackgroundBrush());
-				return TRUE;
-			}
-			break;
-		}
-
 		case NPPM_INTERNAL_REFRESHDARKMODE:
 		{
 			NppDarkMode::autoThemeChildControls(_hSelf);
@@ -1863,7 +1882,7 @@ intptr_t CALLBACK StylerDlg::dlgProc(HWND hwnd, UINT message, WPARAM wParam, LPA
 
         case WM_CTLCOLOREDIT:
         {
-            return NppDarkMode::onCtlColorSofter(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorCtrl(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_CTLCOLORLISTBOX:
@@ -1874,7 +1893,7 @@ intptr_t CALLBACK StylerDlg::dlgProc(HWND hwnd, UINT message, WPARAM wParam, LPA
         case WM_CTLCOLORDLG:
         case WM_CTLCOLORSTATIC:
         {
-            return NppDarkMode::onCtlColorDarker(reinterpret_cast<HDC>(wParam));
+            return NppDarkMode::onCtlColorDlg(reinterpret_cast<HDC>(wParam));
         }
 
         case WM_PRINTCLIENT:
