@@ -21,14 +21,33 @@
 	#define	IDC_BUTTON_CLOSE (IDD_PREFERENCE_BOX + 1)
 	#define	IDC_LIST_DLGTITLE (IDD_PREFERENCE_BOX + 2)
 
+#define	IDD_PREFERENCE_SUB_TOOLBAR 6010    //(IDD_PREFERENCE_BOX + 10)
+	#define	IDC_TOOLBAR_GB_COLORIZATION     (IDD_PREFERENCE_SUB_TOOLBAR + 1)
+	#define	IDC_RADIO_COMPLETE              (IDD_PREFERENCE_SUB_TOOLBAR + 2)
+	#define	IDC_RADIO_PARTIAL               (IDD_PREFERENCE_SUB_TOOLBAR + 3)
+	#define	IDC_TOOLBAR_GB_COLORCHOICE      (IDD_PREFERENCE_SUB_TOOLBAR + 4)
+	#define	IDC_RADIO_DEFAULTCOLOR          (IDD_PREFERENCE_SUB_TOOLBAR + 5)
+	#define	IDC_RADIO_RED                   (IDD_PREFERENCE_SUB_TOOLBAR + 6)
+	#define	IDC_RADIO_GREEN                 (IDD_PREFERENCE_SUB_TOOLBAR + 7)
+	#define	IDC_RADIO_BLUE                  (IDD_PREFERENCE_SUB_TOOLBAR + 8)
+	#define	IDC_RADIO_PURPLE                (IDD_PREFERENCE_SUB_TOOLBAR + 9)
+	#define	IDC_RADIO_CYAN                  (IDD_PREFERENCE_SUB_TOOLBAR + 10)
+	#define	IDC_RADIO_OLIVE                 (IDD_PREFERENCE_SUB_TOOLBAR + 11)
+	#define	IDC_RADIO_YELLOW                (IDD_PREFERENCE_SUB_TOOLBAR + 12)
+	#define	IDC_RADIO_ACCENTCOLOR           (IDD_PREFERENCE_SUB_TOOLBAR + 13)
+	#define	IDC_RADIO_CUSTOMCOLOR           (IDD_PREFERENCE_SUB_TOOLBAR + 14)
+	#define	IDD_ACCENT_TIP_STATIC           (IDD_PREFERENCE_SUB_TOOLBAR + 15)
+
+#define	IDD_PREFERENCE_SUB_TABBAR 6040 //(IDD_PREFERENCE_BOX + 40)
+
 #define	IDD_PREFERENCE_SUB_GENRAL 6100 //(IDD_PREFERENCE_BOX + 100)
-	#define	IDC_TOOLBAR_GB_STATIC (IDD_PREFERENCE_SUB_GENRAL + 1)
+	//#define	IDC_TOOLBAR_GB_STATIC (IDD_PREFERENCE_SUB_GENRAL + 1)
 	#define	IDC_CHECK_HIDE (IDD_PREFERENCE_SUB_GENRAL + 2)
 	#define	IDC_RADIO_SMALLICON (IDD_PREFERENCE_SUB_GENRAL + 3)
 	#define	IDC_RADIO_BIGICON (IDD_PREFERENCE_SUB_GENRAL + 4)
 	#define	IDC_RADIO_STANDARD (IDD_PREFERENCE_SUB_GENRAL + 5)
 
-	#define	IDC_TABBAR_GB_STATIC (IDD_PREFERENCE_SUB_GENRAL + 6)
+	//#define	IDC_TABBAR_GB_STATIC (IDD_PREFERENCE_SUB_GENRAL + 6)
 	#define	IDC_CHECK_REDUCE (IDD_PREFERENCE_SUB_GENRAL + 7)
 	#define	IDC_CHECK_LOCK (IDD_PREFERENCE_SUB_GENRAL + 8)
 	#define	IDC_CHECK_DRAWINACTIVE (IDD_PREFERENCE_SUB_GENRAL + 9)
@@ -54,6 +73,7 @@
 	#define IDC_CHECK_HIDERIGHTSHORTCUTSOFMENUBAR  (IDD_PREFERENCE_SUB_GENRAL + 32)
 	#define IDC_STATUSBAR_GB_STATIC  (IDD_PREFERENCE_SUB_GENRAL + 33)
 	#define IDC_CHECK_HIDESTATUSBAR  (IDD_PREFERENCE_SUB_GENRAL + 34)
+	#define IDC_CHECK_SHOWONLYPINNEDBUTTON (IDD_PREFERENCE_SUB_GENRAL + 35)
 
 #define	IDD_PREFERENCE_SUB_MULTIINSTANCE 6150 //(IDD_PREFERENCE_BOX + 150)
 	#define	IDC_MULTIINST_GB_STATIC (IDD_PREFERENCE_SUB_MULTIINSTANCE + 1)
@@ -120,7 +140,7 @@
 	#define	IDC_CARETBLINKRATE_S_STATIC (IDD_PREFERENCE_SUB_EDITING + 22)
 	#define	IDC_CHECK_CHANGHISTORYMARGIN (IDD_PREFERENCE_SUB_EDITING + 23)
 	#define	IDC_DISTRACTIONFREE_SLIDER (IDD_PREFERENCE_SUB_EDITING + 24)
-	//#define	IDC_CHECK_MULTISELECTION (IDD_PREFERENCE_SUB_EDITING + 25)
+	#define	IDC_CHECK_SELECTEDTEXTSINGLECOLOR (IDD_PREFERENCE_SUB_EDITING + 25)
 
 	#define	IDC_RADIO_FOLDMARGENONE (IDD_PREFERENCE_SUB_EDITING + 26)
 
@@ -175,7 +195,7 @@
 	#define	IDD_STATIC_BLABLA (IDD_PREFERENCE_SUB_DELIMITER + 7)
 	#define	IDD_STATIC_BLABLA2NDLINE (IDD_PREFERENCE_SUB_DELIMITER + 8)
 
-#define	IDD_PREFERENCE_SUB_CLOUD_LINK 6260 //(IDD_PREFERENCE_BOX + 250)
+#define	IDD_PREFERENCE_SUB_CLOUD_LINK 6260 //(IDD_PREFERENCE_BOX + 260)
 	#define	IDC_SETTINGSONCLOUD_WARNING_STATIC (IDD_PREFERENCE_SUB_CLOUD_LINK + 1)
 	#define	IDC_SETTINGSONCLOUD_GB_STATIC (IDD_PREFERENCE_SUB_CLOUD_LINK + 2)
 	#define	IDC_NOCLOUD_RADIO (IDD_PREFERENCE_SUB_CLOUD_LINK + 3)
