@@ -611,7 +611,7 @@ void ToolBar::resizeIconsDpi(UINT dpi)
 	reset(true);
 }
 
-void ToolBar::addToRebar(ReBar * rebar) 
+void ToolBar::addToRebar(ReBar* rebar)
 {
 	if (_pRebar)
 		return;
@@ -636,42 +636,6 @@ void ToolBar::addToRebar(ReBar * rebar)
 	_rbBand.fMask   = RBBIM_CHILD | RBBIM_CHILDSIZE | RBBIM_IDEALSIZE | RBBIM_SIZE;
 }
 
-constexpr UINT_PTR g_rebarSubclassID = 42;
-
-LRESULT CALLBACK RebarSubclass(
-	HWND hWnd,
-	UINT uMsg,
-	WPARAM wParam,
-	LPARAM lParam,
-	UINT_PTR uIdSubclass,
-	DWORD_PTR dwRefData
-)
-{
-	UNREFERENCED_PARAMETER(dwRefData);
-	UNREFERENCED_PARAMETER(uIdSubclass);
-
-	switch (uMsg)
-	{
-		case WM_ERASEBKGND:
-			if (NppDarkMode::isEnabled())
-			{
-				RECT rc{};
-				GetClientRect(hWnd, &rc);
-				FillRect((HDC)wParam, &rc, NppDarkMode::getDarkerBackgroundBrush());
-				return TRUE;
-			}
-			else
-			{
-				break;
-			}
-
-		case WM_NCDESTROY:
-			RemoveWindowSubclass(hWnd, RebarSubclass, g_rebarSubclassID);
-			break;
-	}
-	return DefSubclassProc(hWnd, uMsg, wParam, lParam);
-}
-
 void ReBar::init(HINSTANCE hInst, HWND hPere)
 {
 	Window::init(hInst, hPere);
@@ -681,7 +645,7 @@ void ReBar::init(HINSTANCE hInst, HWND hPere)
 							WS_CHILD|WS_VISIBLE | WS_CLIPSIBLINGS | WS_CLIPCHILDREN | RBS_VARHEIGHT | CCS_NODIVIDER | CCS_NOPARENTALIGN,
 							0,0,0,0, _hParent, NULL, _hInst, NULL);
 
-	SetWindowSubclass(_hSelf, RebarSubclass, g_rebarSubclassID, 0);
+	NppDarkMode::autoSubclassCtlColor(_hSelf);
 
 	REBARINFO rbi{};
 	ZeroMemory(&rbi, sizeof(REBARINFO));
